summaryrefslogtreecommitdiff
path: root/gcc/testsuite/gcc.dg/tree-ssa/loop-4.c
diff options
context:
space:
mode:
authorrakdver <rakdver@138bc75d-0d04-0410-961f-82ee72b054a4>2005-01-09 18:58:11 +0000
committerrakdver <rakdver@138bc75d-0d04-0410-961f-82ee72b054a4>2005-01-09 18:58:11 +0000
commitbb9223595906e2dc3554b1eb71daf83e1a744bda (patch)
tree89c8d32acb8cc2ee06afd1c2e3ad4e894e477979 /gcc/testsuite/gcc.dg/tree-ssa/loop-4.c
parentbfc873eeeb915f2fa67d6af46a9ff6b337d492cb (diff)
downloadgcc-bb9223595906e2dc3554b1eb71daf83e1a744bda.tar.gz
* gcc.dg/tree-ssa/loop-4.c: Fix outcome.
git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@93116 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/testsuite/gcc.dg/tree-ssa/loop-4.c')
-rw-r--r--gcc/testsuite/gcc.dg/tree-ssa/loop-4.c13
1 files changed, 11 insertions, 2 deletions
diff --git a/gcc/testsuite/gcc.dg/tree-ssa/loop-4.c b/gcc/testsuite/gcc.dg/tree-ssa/loop-4.c
index a1dabfd9bcb..8ba535b597a 100644
--- a/gcc/testsuite/gcc.dg/tree-ssa/loop-4.c
+++ b/gcc/testsuite/gcc.dg/tree-ssa/loop-4.c
@@ -23,9 +23,18 @@ void xxx(void)
arr_base[iter].y = foo ();
}
-/* Access to arr_base[iter].y should be strength reduced. */
+/* Access to arr_base[iter].y should be strength reduced. Depending on
+ whether we have an addressing mode of type [base + offset], one of the
+ following forms might get chosen:
-/* { dg-final { scan-tree-dump-times "arr_base\[^\\n\\r\]*=" 0 "vars" } } */
+ -- induction variable with base &arr_base[0].y, the memory access of
+ form *iv = ...
+ -- induction variable with base 0, the memory access of form
+ *(iv + &arr_base[0].y) = ...
+
+ In any case, we should not have 'arr_base.[^0].* =' */
+
+/* { dg-final { scan-tree-dump-times "arr_base.\[^0\]\[^\\n\\r\]*=" 0 "vars" } } */
/* And the original induction variable should be eliminated. */